@@ -2,6 +2,7 @@ import os
 import logging
 import time
 import requests
+import click_spinner
 
 from .coorcal import generate_coordinate
 
@@ -41,7 +42,9 @@ PAGE_FIELDS = ['id',
                'name',
                'cover.fields(id,source)',
                'picture.type(large)',
-               'location']
+               'location',
+               'category',
+               'link']
 
 # Get App Access Token
 token = requests.get(BASE_URL +
@@ -126,19 +129,19 @@ def get_events_by_location(latitude, longitude, place_type='*',
     """
     CIRCLE = (latitude, longitude, distance, )
     events = []
+    with click_spinner.spinner():
+        for point in generate_coordinate(*CIRCLE, scan_radius=scan_radius):
+            page_list = get_page_ids(latitude, longitude, place_type,
+                                     distance, limit)
+            for page_id in page_list:
+                nodes = get_events(page_id, base_time=base_time,
+                                   fields=fields)[page_id]
+                if 'events' in nodes:
+                    events.append(nodes['events']['data'])
+                else:
+                    pass
 
-    for point in generate_coordinate(*CIRCLE, scan_radius=scan_radius):
-        page_list = get_page_ids(latitude, longitude, place_type,
-                                 distance, limit)
-        for page_id in page_list:
-            nodes = get_events(page_id, base_time=base_time,
-                               fields=fields)[page_id]
-            if 'events' in nodes:
-                events.append(nodes['events']['data'])
-            else:
-                pass
-
-    return events
+        return events
 
 
 def get_page_info(page_id, fields=PAGE_FIELDS):
